#
# spec file for package azote
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print(get_python_lib())")}
Name:           azote
Version:        1.15.0
Release:        1.1
Summary:        Wallpaper manager for Sway, i3 and some other WMs
License:        GPL-3.0-only
Group:          Productivity/Graphics/Viewers
URL:            https://github.com/nwg-piotr/azote
Source:         https://github.com/nwg-piotr/azote/archive/refs/tags/v%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  gobject-introspection
BuildRequires:  python3-Pillow
BuildRequires:  python3-gobject
BuildRequires:  python3-setuptools
# for screen color picker on both Sway and X11
Requires:       ImageMagick
Requires:       feh
Requires:       python3-Pillow
# for alacritty.yml toolbox
Requires:       python3-PyYAML
Requires:       python3-Send2Trash
Requires:       python3-gobject
Requires:       python3-gobject-Gdk
Requires:       wget
Requires:       wmctrl
Requires:       xrandr
BuildArch:      noarch

%description
Azote is a GTK+ 3-based picture browser and a wallpaper setter, as the frontend to the swaybg (Sway/Wayland) and feh (X windows) commands.

%prep
%setup -q

%build
%python3_build

%install
%python3_install
install -D -m 0644 dist/azote.svg %{buildroot}%{_datadir}/azote/azote.svg
install -D -m 0644 dist/azote.desktop %{buildroot}%{_datadir}/applications/azote.desktop
%fdupes  %{buildroot}/

%files
%license LICENSE
%doc README.md
%{_bindir}/azote
%{_datadir}/applications/azote.desktop
%{_datadir}/azote/
%{python_sitelib}/%{name}
%{python_sitelib}/%{name}-%{version}*-info

%changelog
* Wed Apr  2 2025 Michael Vetter <mvetter@suse.com>
- Update to 1.15.0:
  * Support for JPEG XL images added to Pillow through pillow-jxl-plugin #214
  * Support for using miraclemsg when miracle-wm is detected #213
* Thu Mar 27 2025 Michael Vetter <mvetter@suse.com>
- Update to 1.14.2:
  * Added Czech lang file #210
  * Added Turkish lang file #211
* Mon Dec 30 2024 Michael Vetter <mvetter@suse.com>
- Update to 1.14.1:
  * Added support for libayatana-appindicator3 #206.
* Mon Dec 16 2024 Michael Vetter <mvetter@suse.com>
- Update to 1.14:
  * Fixed displays detection on X11 #203 #202.
* Wed Sep 25 2024 Michael Vetter <mvetter@suse.com>
- Update to 1.13.1:
  * Fix path to the helper image used when creating a thumbnail
    for images with non-standard aspect ratios. Closes #197.
* Fri Aug 23 2024 Michael Vetter <mvetter@suse.com>
- Update to 1.13.0:
  * fixed SyntaxWarning for invalid escape sequence in main.py #193
  * adjustment to the current imagemagick version (convert -> magick);
  * workaround for Hyprland 0.42.0 oddity:
    If you use generic display names instead of output names, and your display
    has the serial value empty, Hyprland for some reason expects a space at the
    end of the output description (called 'Generic display name' in Azote).
* Wed May 29 2024 Michael Vetter <mvetter@suse.com>
- Update to 1.12.9:
  * Fix broken images path
* Mon May 27 2024 Michael Vetter <mvetter@suse.com>
- Update to 1.12.8:
  * Fix no such file in directory bug #189
* Fri May  3 2024 Michael Vetter <mvetter@suse.com>
- Update to 1.12.7:
  * Get ready for Hyprland socket files moved to $XDG_RUNTIME_DIR/hypr
* Thu Apr  4 2024 Michael Vetter <mvetter@suse.com>
- Update to 1.12.6:
  * Added Italian translation #186
* Mon Feb 26 2024 Michael Vetter <mvetter@suse.com>
- Update to 1.12.5:
  * Fixed silent crash on file extension in uppercase.
* Sat Jan 27 2024 Michael Vetter <mvetter@suse.com>
- Update to 1.12.4:
  * Documentation updated
* Tue Jul 11 2023 Michael Vetter <mvetter@suse.com>
- Update to 1.12.3:
  * Fix crash on spaces in directory names #184
* Wed Jul  5 2023 Michael Vetter <mvetter@suse.com>
- Update to 1.12.2:
  * Fix crash on attempt to split an image #183
* Fri Jun 23 2023 Michael Vetter <mvetter@suse.com>
- Update 1.12.1
  * Add Russian translation #182
* Tue May 30 2023 Michael Vetter <mvetter@suse.com>
- Update to 1.12.0:
  * Fix generic name creation when the serial number field is
    empty / "none";
  * As the serial numbers returned by sway and Hyprland may be
    different for some reason, from now on we use the new
    ~/.azotebg-hyprland setter script on Hyprland.
    Edit your hyprland.conf.
* Thu Mar 30 2023 Michael Vetter <mvetter@suse.com>
- Update to 1.11.0:
  * Increase awk compatibility
  * Add Hyprland-specific displays detection
  * Fix imports
  * Fix example wallpaper
* Thu Mar  9 2023 Michael Vetter <mvetter@suse.com>
- Update to 1.10.1:
  * Fix lang files path
* Thu Mar  9 2023 Michael Vetter <mvetter@suse.com>
- Updaet to 1.10.0:
  * Multiple langs support unified with nwg-shell;
  * Added "Close" button to unify this matter as well.
* Fri Nov 11 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.9.7:
  * Fixed regression introduced in #166, that caused a mess in
    the ./azotebg file. Closes #169.
* Wed Nov  2 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.9.6:
  * added 2 lines to check if the /usr/share/backgrounds/nwg-shell path
    exists, and set it as the sample_dir, if so.
* Wed Jun  1 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.9.5:
  * Fixed launcher script not working on Fedora #163
* Mon May 30 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.9.4:
  * dropped distutils dependency #159
  * fixed key error occurring when generic display names used on a
    non-sway wlroots-based WM #162
* Mon May 30 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.9.3:
  * search more backgrounds sub-dirs on first run
* Wed Nov  3 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.9.2:
  * escape some special characters #155
  * fixed improper environment detection on dwl, and possibly some
    other wlroots-based compositors
* Mon Mar 29 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.9.1:
  * [sway] Added the "Use generic display names" preferences
    switch (#143).
* Mon Mar 15 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.9.0:
  * Restore wallpapers in use on startup;
  * some tricky fixes to xrandr / fehbg support on multi-headed setups
  * double click no longer applies the selected wallpaper to
    outputs, just to displays preview;
  * added check buttons to split current image between selected
    outputs only.
* Mon Jan 11 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.8.2:
  * sway: fixed crash on display connected, but turned off #110
  * app icon re-scaled, moved to /usr/share/pixmaps
  * set icon name for X11 and app_id for Wayland
* Mon Oct  5 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.8.1:
  * screen height measurement on sway simplified
  * Esc key closes the Azote window
  * dialog windows' behaviour unified
* Thu Oct  1 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.8.0:
  * added fix to avoid crashes on X11, when a display is connected, but turned off #110
  * added CLI messages on missing optional dependencies #101
  * screen height is deprecated #108 issue fixed in slightly tricky way
* Mon Sep 14 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.7.14:
  * Added possibility to open images with swappy (.png only)
  * fixed crash on the stored wallpaper folder path not found #102
  * added support for Wayfire (possibly also for other wlroots-based
    Wayland compositors); swaybg and wlr-randr packages required.
* Tue Jun 23 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.7.12:
  * scale and crop to triple display width / height;
  * split vertical images vertically (is_horizontal = width >= height);
  * detect which screen Azote window is displayed on; the screen
    dimensions will be used as the base of the Scale and crop to
  double/triple screen width/height option. This may be useful
  if you use multiple-headed setup with various screen resolutions.
  * added some error handling on colour definitions missing from
    the allacritty.yml file.
* Wed Jun  3 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.7.11:
  * Python version-independent launcher script #87
* Wed May 20 2020 Michael Vetter <mvetter@suse.com>
- Add BuildRequires gobject-introspection and python3-gobject-Gdk
* Tue May 19 2020 Michael Vetter <mvetter@suse.com>
- Replcae python3-yaml with python3-PyYAML
- Add requires on imagemagick
* Wed Apr 29 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.7.10:
  * path to the config dir w/ XDG_CONFIG_HOME corrected
  * "Open with" issue #82 fixed.
* Sun Jan 12 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.7.8:
  * styling clicked palette button with button#color-btn-selected
    added (for colour-blind people like myself);
  * colour picker: colour image converted into the Gtk.ColorButton
    class, to allow the colour edition;
  * added tracking the currently selected wallpapers folder for
    file addition / deletion: switchable, configurable (every 5 sec by default);
  * tray status icon added, i.a. to indicate the tracking on/off state;
  * python-send2trash from now on recommended as an obligatory dependency.
- Remove azote-python-version.patch
* Mon Jul  1 2019 mvetter@suse.com
- Add azote-python-version.patch: Use python3
* Mon Jul  1 2019 mvetter@suse.com
- Package azote 1.1.1 for openSUSE
